from comms_wrapper import *

def main():
    '''
    KEYBOARD LISTENER

    If you want to use key commands in your process, create the Key() instance.
    '''
    key = Key()


    '''
    DEFINE ARDUINOS

    Define the Arduino() instance as shown below. 
    descriptiveDeviceName: Name of the device you choose. e.g.: "Measurment arduino uno"
    portName: Port the arduino is connected. Check in your teminal/device manager
              e.g.: "/dev/tty/ACM0" on linux,  "COM1" on windows, "/dev/tty.usbserial1 on MacOS"
    baudrate: The baudrate defined in your Arduino .ino file (Serial.begin(BAUDRATE);)

    You can define as many Arduinos as you have connected. e.g.: see arduino2 below arduino1

    Defining arduinos does not estabilish a connection. 
    '''
    arduino1 = Arduino(descriptiveDeviceName="myArduino", portName="/dev/ttyACM0", baudrate=115200)
    #arduino2 = Arduino(descriptiveDeviceName="myArduino2", portName="/dev/ttyACM2", baudrate=115200)


    '''
    DEFINE MESSAGE NAMES

    To receive multiple messages from the Arduino, you must define name of the message. 
    The names here, must perfectly match what was defined on the Arduino .ino file.#

    You must define this for every arduino.
    '''
    arduino1.define_message_names(["msgA", "msgB"])
    #arduino2.define_message_names(["msgC", "msgD"])
    
    '''
    CONNECTING WITH THE ARDUINO

    Call the connect_and_handshake() method to estabilish a reliable connection with the arduino. 
    You must perform this for every arduino.
    '''
    arduino1.connect_and_handshake()
    #arduino2.connect_and_handshake()

    
    # Your main loop/process
    while 1: 
        
        
        '''
        RECEIVING MESSAGES
        
        This is how you receive messages from the arduino side
        Calling receive_message() will read the serial bus.
        This will be stored in the class variable receivedMessages
        '''
        arduino1.receive_message()
        print(arduino1.receivedMessages)

        #arduino1.receive_message()
        #print(arduino1.receivedMessages)

        '''
        SENDING MESSAGES

        You can send a string by simply calling send_message()
        '''

        '''
        KEY COMMANDS

        If you created an instance of Key(), you can use your keyboard easily.
        Read your key commands by calling keyPress. 
        This will return the key press while the key is pressed. When released, it will return None.
        If you instead want the stored most recent key press, use keyPressedLatching
        '''
        if key.keyPress == "f": 
            arduino1.send_message("apples")
            #arduino2.send_message("oranges")

        if key.keyPress == "g":
            arduino1.send_message("bananas")
            #arduino2.send_message("grapes")

    

        '''
        DEBUGGING
        
        Comment out the below code to debug the system
        This will show you relevant info to see how your system is behaving
        
        You can obtain all the information by specifying the verbose mode => arduino1.debug(verbose = True))
        '''
        arduino1.debug()
        #arduino2.debug()

        '''
        This delay is not critical. It is only in place to 
            a) Demonstrate any process blocking the execution does not affect the communication
            b) Make the printout easy to read
        '''
        time.sleep(0.2)


if __name__ == '__main__':
    main()